@@ -2,10 +2,11 @@ from io import BytesIO
 from os import makedirs, path
 from configparser import ConfigParser, SectionProxy
 from rich import print
-from jinja2 import Environment, FileSystemLoader
+from jinja2 import Environment
 import click
 from docker import APIClient, errors
 from freshenv.console import console
+from freshenv.provision import get_dockerfile_path
 from requests import exceptions
 
 
@@ -14,8 +15,8 @@ freshenv_config_location = homedir + "/.freshenv/freshenv"
 
 
 def create_dockerfile(base: str, install: str, cmd: str) -> str:
-    env = Environment(loader=FileSystemLoader("freshenv/templates"), autoescape=True)
-    template = env.get_template('simple')
+    contents = get_dockerfile_path("simple")
+    template = Environment(autoescape=True).from_string(str(contents.decode("utf-8")))
     build_template = template.render(base=base, install=install, cmd=cmd)
     return build_template
 
@@ -43,11 +44,11 @@ def env_exists(flavour: str) -> bool:
 def mandatory_keys_exists(flavour: str) -> bool:
     config = ConfigParser()
     config.read(freshenv_config_location)
-    if "BASE" not in config[flavour]:
+    if "base" not in config[flavour]:
         return False
-    if "INSTALL" not in config[flavour]:
+    if "install" not in config[flavour]:
         return False
-    if "CMD" not in config[flavour]:
+    if "cmd" not in config[flavour]:
         return False
     return True
 
@@ -83,9 +84,13 @@ def build(flavour: str, logs: bool) -> None:
     try:
         client = APIClient(base_url="unix://var/run/docker.sock")
         with console.status("Building custom flavour...", spinner="point"):
-            for line in client.build(fileobj=BytesIO(flavour_dockerfile.encode('utf-8')), tag=f"raiyanyahya/{flavour}/{flavour}", rm=True, pull=True, decode=True):
+            for line in client.build(fileobj=BytesIO(flavour_dockerfile.encode("utf-8")), tag=f"raiyanyahya/freshenv-flavours/{flavour}", rm=True, pull=True, decode=True):
+                if "errorDetail" in line:
+                    raise Exception(line["errorDetail"]["message"])
                 if logs:
                     print(line)
+        print(f":party_popper: Successfully built custom flavour {flavour}. You can provision it by running [bold]freshenv provision -f {flavour}[/bold].")
     except (errors.APIError, exceptions.HTTPError):
-        print(":x: Custom flavour could not be built.")
-    print(f":party_popper: Successfully built custom flavour {flavour}. You can provision it by running [bold]freshenv -provision -f {flavour}[/bold].")
\ No newline at end of file
+        print(":x: Custom flavour could not be built. Try again after cleaning up with [bold]fr clean --force [/bold]")
+    except Exception as e:
+        print(f":x: Custom flavour could not be built due to the error: {e}.")
\ No newline at end of file
